@@ -31,10 +31,8 @@ import httplib
 import socket
 import re
 import DistUpgrade.DistUpgradeCache
-from DistUpgrade.DistUpgradeCache import NotEnoughFreeSpaceError
 from gettext import gettext as _
 from UpdateList import UpdateOrigin
-from utils import ExecutionTime
 
 SYNAPTIC_PINFILE = "/var/lib/synaptic/preferences"
 CHANGELOGS_URI="http://changelogs.ubuntu.com/changelogs/pool/%s/%s/%s/%s_%s/%s"
@@ -174,7 +172,6 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
         section = pkg._pcache._depcache.get_candidate_ver(pkg._pkg).section
 
         # get the source version, start with the binaries version
-        binver = pkg.candidateVersion
         srcver_epoch = pkg.candidateVersion
         srcver = self._strip_epoch(srcver_epoch)
         #print "bin: %s" % binver
@@ -203,7 +200,6 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
         alllines = ""
         regexp = "^%s \((.*)\)(.*)$" % (re.escape(srcpkg))
         
-        i=0
         while True:
             line = changelog.readline()
             if line == "":
@@ -276,7 +272,7 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
         " get the NEWS.Debian file from the changelogs location "
         try:
             news = self._get_changelog_or_news(name, "NEWS.Debian", True)
-        except Exception, e:
+        except Exception:
             return
         if news:
             self.all_news[name] = news
@@ -284,7 +280,7 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
     def get_changelog(self, name):
         " get the changelog file from the changelog location "
         origins = self[name].candidateOrigin
-        self.all_changes[name] = _("Changes for the versions:\n%s\n%s\n\n") % (self[name].installedVersion, self[name].candidateVersion)
+        self.all_changes[name] = _("Changes for the versions:\nInstalled version: %s\nAvailable version: %s\n\n") % (self[name].installedVersion, self[name].candidateVersion)
         if not self.CHANGELOG_ORIGIN in [o.origin for o in origins]:
             # Try non official changelog location
             changelogs_uri_binary = self._guess_third_party_changelogs_uri_by_binary(name)
@@ -298,7 +294,7 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
                     except urllib2.HTTPError, e:
                         # no changelogs_uri or 404
                         error_message = _(
-                            "This change is not coming from a "
+                            "This update does not come from a "
                             "source that supports changelogs.")
                     except (IOError, httplib.BadStatusLine, socket.error), e:
                         # network errors and others
