@@ -1,4 +1,4 @@
-# UpdateManager.py 
+# UpdateManager.py
 #  
 #  Copyright (c) 2004-2010 Canonical
 #                2004 Michiel Sikkes
@@ -26,23 +26,20 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 #  USA
 
-import pygtk
-pygtk.require('2.0')
-import gtk
-import gtk.gdk
-import gconf
-import gobject
-gobject.threads_init()
-import glib
+from gi.repository import Gtk
+from gi.repository import Gdk
+from gi.repository import GObject
+from gi.repository import GLib
+from gi.repository import Gio
+GObject.threads_init()
+from gi.repository import Pango
 
 import warnings
 warnings.filterwarnings("ignore", "Accessed deprecated property", DeprecationWarning)
-import apt
+
 import apt_pkg
 
 import gettext
-import copy
-import string
 import sys
 import os
 import os.path
@@ -50,13 +47,7 @@ import stat
 import re
 import locale
 import logging
-import tempfile
-import pango
 import subprocess
-import pwd
-import urllib2
-import httplib
-import socket
 import time
 import thread
 import xml.sax.saxutils
@@ -72,18 +63,24 @@ from gettext import gettext as _
 from gettext import ngettext
 
 
-from Core.utils import *
+from Core.utils import (is_unity_running,
+                        humanize_size, 
+                        init_proxy, 
+                        on_battery,
+                        inhibit_sleep,
+                        allow_sleep)
 from Core.UpdateList import UpdateList
-from Core.MyCache import MyCache, NotEnoughFreeSpaceError
-from Core.MetaRelease import Dist
+from Core.MyCache import MyCache
 from Core.AlertWatcher import AlertWatcher
-from SafeGConfClient import SafeGConfClient
 
+from DistUpgrade.DistUpgradeCache import NotEnoughFreeSpaceError
 from DistUpgradeFetcher import DistUpgradeFetcherGtk
+
 from ChangelogViewer import ChangelogViewer
-from SimpleGtkbuilderApp import SimpleGtkbuilderApp
-from HelpViewer import HelpViewer
+from SimpleGtk3builderApp import SimpleGtkbuilderApp
 from MetaReleaseGObject import MetaRelease
+from UnitySupport import UnitySupport
+
 
 #import pdb
 
@@ -109,14 +106,14 @@ def show_dist_no_longer_supported_dialog(parent=None):
         _("You will not get any further security fixes or critical "
           "updates. "
           "Please upgrade to a later version of Ubuntu Linux."))
-    dialog = gtk.MessageDialog(parent, 0, gtk.MESSAGE_WARNING,
-                               gtk.BUTTONS_CLOSE,"")
+    dialog = Gtk.MessageDialog(parent, 0, Gtk.MessageType.WARNING,
+                               Gtk.ButtonsType.CLOSE,"")
     dialog.set_title("")
     dialog.set_markup(msg)
-    button = gtk.LinkButton(uri="http://www.ubuntu.com/releaseendoflife",
+    button = Gtk.LinkButton(uri="http://www.ubuntu.com/releaseendoflife",
                             label=_("Upgrade information"))
     button.show()
-    dialog.get_content_area().pack_end(button)
+    dialog.get_content_area().pack_end(button, True, True, 0)
     # this data used in the test to get the dialog
     if parent:
         parent.set_data("no-longer-supported-nag", dialog)
@@ -164,7 +161,7 @@ class UpdateManagerDbusController(dbus.service.Object):
         pass	
 
     def _on_network_alert(self, watcher, state):
-        if state == NetworkManagerHelper.NM_STATE_CONNECTED:
+        if state in NetworkManagerHelper.NM_STATE_CONNECTED_LIST:
             self.connected = True
         else:
             self.connected = False
@@ -176,9 +173,9 @@ class UpdateManager(SimpleGtkbuilderApp):
 
   def __init__(self, datadir, options):
     self.setupDbus()
-    gtk.window_set_default_icon_name("update-manager")
+    Gtk.Window.set_default_icon_name("update-manager")
     self.datadir = datadir
-    SimpleGtkbuilderApp.__init__(self, datadir+"glade/UpdateManager.ui",
+    SimpleGtkbuilderApp.__init__(self, datadir+"gtkbuilder/UpdateManager.ui",
                                  "update-manager")
     gettext.bindtextdomain("update-manager", "/usr/share/locale")
     gettext.textdomain("update-manager")
@@ -191,7 +188,7 @@ class UpdateManager(SimpleGtkbuilderApp):
     self.sleep_cookie = None
     self.sleep_dev = None
 
-    self.image_logo.set_from_icon_name("update-manager", gtk.ICON_SIZE_DIALOG)
+    self.image_logo.set_from_icon_name("update-manager", Gtk.IconSize.DIALOG)
     self.window_main.set_sensitive(False)
     self.window_main.grab_focus()
     self.button_close.grab_focus()
@@ -203,7 +200,7 @@ class UpdateManager(SimpleGtkbuilderApp):
     self.textview_changes.show()
     self.scrolledwindow_changes.add(self.textview_changes)
     changes_buffer = self.textview_changes.get_buffer()
-    changes_buffer.create_tag("versiontag", weight=pango.WEIGHT_BOLD)
+    changes_buffer.create_tag("versiontag", weight=Pango.Weight.BOLD)
 
     # expander
     self.expander_details.connect("notify::expanded", self.activate_details)
@@ -213,29 +210,28 @@ class UpdateManager(SimpleGtkbuilderApp):
     self.button_close.connect("clicked", lambda w: self.exit())
 
     # the treeview (move into it's own code!)
-    self.store = gtk.ListStore(str, str, gobject.TYPE_PYOBJECT, 
-                               gobject.TYPE_PYOBJECT, bool)
+    self.store = Gtk.ListStore(str, str, GObject.TYPE_PYOBJECT, 
+                               GObject.TYPE_PYOBJECT, bool)
     self.treeview_update.set_model(self.store)
     self.treeview_update.set_headers_clickable(True);
-    self.treeview_update.set_direction(gtk.TEXT_DIR_LTR)
+    self.treeview_update.set_direction(Gtk.TextDirection.LTR)
 
-    tr = gtk.CellRendererText()
+    tr = Gtk.CellRendererText()
     tr.set_property("xpad", 6)
     tr.set_property("ypad", 6)
-    cr = gtk.CellRendererToggle()
+    cr = Gtk.CellRendererToggle()
     cr.set_property("activatable", True)
     cr.set_property("xpad", 6)
     cr.connect("toggled", self.toggled)
 
-    column_install = gtk.TreeViewColumn("Install", cr, active=LIST_TOGGLE_CHECKED)
+    column_install = Gtk.TreeViewColumn("Install", cr, active=LIST_TOGGLE_CHECKED)
     column_install.set_cell_data_func (cr, self.install_column_view_func)
-    column = gtk.TreeViewColumn("Name", tr, markup=LIST_CONTENTS)
+    column = Gtk.TreeViewColumn("Name", tr, markup=LIST_CONTENTS)
     column.set_resizable(True)
-    major,minor,patch = gtk.pygtk_version
 
-    column_install.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
+    column_install.set_sizing(Gtk.TreeViewColumnSizing.FIXED)
     column_install.set_fixed_width(30)
-    column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
+    column.set_sizing(Gtk.TreeViewColumnSizing.FIXED)
     column.set_fixed_width(100)
     self.treeview_update.set_fixed_height_mode(False)
 
@@ -244,7 +240,6 @@ class UpdateManager(SimpleGtkbuilderApp):
     self.treeview_update.append_column(column)
     self.treeview_update.set_search_column(LIST_NAME)
     self.treeview_update.connect("button-press-event", self.show_context_menu)
-    self.treeview_update.connect("row-activated", self.row_activated)
 
     # setup the help viewer and disable the help button if there
     # is no viewer available
@@ -255,14 +250,14 @@ class UpdateManager(SimpleGtkbuilderApp):
     if not os.path.exists("/usr/bin/software-properties-gtk"):
         self.button_settings.set_sensitive(False)
 
-    self.gconfclient = SafeGConfClient()
-    init_proxy(self.gconfclient)
+    self.settings =  Gio.Settings("com.ubuntu.update-manager")
+    init_proxy(self.settings)
     # init show version
-    self.show_versions = self.gconfclient.get_bool("/apps/update-manager/show_versions")
+    self.show_versions = self.settings.get_boolean("show-versions")
     # init summary_before_name
-    self.summary_before_name = self.gconfclient.get_bool("/apps/update-manager/summary_before_name")
+    self.summary_before_name = self.settings.get_boolean("summary-before-name")
     # keep track when we run (for update-notifier)
-    self.gconfclient.set_int("/apps/update-manager/launch_time", int(time.time()))
+    self.settings.set_int("launch-time", int(time.time()))
 
     # get progress object
     self.progress = GtkProgress.GtkOpProgressInline(
@@ -282,12 +277,18 @@ class UpdateManager(SimpleGtkbuilderApp):
     # get the install backend
     self.install_backend = backend.get_backend(self.window_main)
     self.install_backend.connect("action-done", self._on_backend_done)
+
+    # Create Unity launcher quicklist
+    # FIXME: instead of passing parent we really should just send signals
+    self.unity = UnitySupport(parent=self)
+
     # it can only the iconified *after* it is shown (even if the docs
     # claim otherwise)
     if options.no_focus_on_map:
         self.window_main.iconify()
         self.window_main.stick()
         self.window_main.set_urgency_hint(True)
+        self.unity.set_urgency(True)
         self.initial_focus_id = self.window_main.connect(
             "focus-in-event", self.on_initial_focus_in)
     
@@ -297,10 +298,16 @@ class UpdateManager(SimpleGtkbuilderApp):
     self.alert_watcher.connect("battery-alert", self._on_battery_alert)
     self.alert_watcher.connect("network-3g-alert", self._on_network_3g_alert)
 
+
+  def install_all_updates (self, menu, menuitem, data):
+    self.select_all_updgrades (None)
+    self.on_button_install_clicked (None)
+
   def on_initial_focus_in(self, widget, event):
       """callback run on initial focus-in (if started unmapped)"""
       widget.unstick()
       widget.set_urgency_hint(False)
+      self.unity.set_urgency(False)
       self.window_main.disconnect(self.initial_focus_id)
       return False
 
@@ -311,14 +318,13 @@ class UpdateManager(SimpleGtkbuilderApp):
           self.dialog_on_battery.set_title("")
           res = self.dialog_on_battery.run()
           self.dialog_on_battery.hide()
-          if res != gtk.RESPONSE_YES:
+          if res != Gtk.ResponseType.YES:
               sys.exit()
 
-  def install_column_view_func(self, cell_layout, renderer, model, iter):
+  def install_column_view_func(self, cell_layout, renderer, model, iter, data):
     pkg = model.get_value(iter, LIST_PKG)
-    # hide it if we are only a header line
-    renderer.set_property("visible", pkg != None)
     if pkg is None:
+	renderer.set_property("activatable", True)
         return
     current_state = renderer.get_property("active")
     to_install = pkg.marked_install or pkg.marked_upgrade
@@ -348,14 +354,14 @@ class UpdateManager(SimpleGtkbuilderApp):
         iface.bringToFront()
         #print "send bringToFront"
         sys.exit(0)
-    except dbus.DBusException, e:
+    except dbus.DBusException:
          #print "no listening object (%s) "% e
          bus_name = dbus.service.BusName('org.freedesktop.UpdateManager',bus)
          self.dbusController = UpdateManagerDbusController(self, bus_name)
 
 
   def on_checkbutton_reminder_toggled(self, checkbutton):
-    self.gconfclient.set_bool("/apps/update-manager/remind_reload",
+    self.settings.set_boolean("remind-reload",
                               not checkbutton.get_active())
 
   def close(self, widget, data=None):
@@ -379,7 +385,7 @@ class UpdateManager(SimpleGtkbuilderApp):
       author_match = re.match("^.*--.*<.*@.*>.*$", line)
       if version_match:
         version = version_match.group(1)
-	upload_archive = version_match.group(2).strip()
+	#upload_archive = version_match.group(2).strip()
         version_text = _("Version %s: \n") % version
         changes_buffer.insert_with_tags_by_name(end_iter, version_text, "versiontag")
       elif (author_match):
@@ -443,11 +449,11 @@ class UpdateManager(SimpleGtkbuilderApp):
       if self.expander_details.get_expanded():
         lock = thread.allocate_lock()
         lock.acquire()
-        t=thread.start_new_thread(self.cache.get_news_and_changelog,(name,lock))
+        thread.start_new_thread(self.cache.get_news_and_changelog,(name,lock))
         changes_buffer.set_text("%s\n" % _("Downloading list of changes..."))
         iter = changes_buffer.get_iter_at_line(1)
         anchor = changes_buffer.create_child_anchor(iter)
-        button = gtk.Button(stock="gtk-cancel")
+        button = Gtk.Button(stock="gtk-cancel")
         self.textview_changes.add_child_at_anchor(button, anchor)
         button.show()
         id = button.connect("clicked",
@@ -455,11 +461,12 @@ class UpdateManager(SimpleGtkbuilderApp):
         # wait for the dl-thread
         while lock.locked():
           time.sleep(0.01)
-          while gtk.events_pending():
-            gtk.main_iteration()
+          while Gtk.events_pending():
+            Gtk.main_iteration()
         # download finished (or canceld, or time-out)
         button.hide()
-        button.disconnect(id);
+        if button.handler_is_connected(id):
+            button.disconnect(id)
     # check if we still are in the right pkg (the download may have taken
     # some time and the user may have clicked on a new pkg)
     path  = widget.get_cursor()[0]
@@ -482,19 +489,24 @@ class UpdateManager(SimpleGtkbuilderApp):
     """
     Show a context menu if a right click was performed on an update entry
     """
-    if event.type == gtk.gdk.BUTTON_PRESS and event.button == 3:
-        menu = gtk.Menu()
-        item_select_none = gtk.MenuItem(_("_Uncheck All"))
+    if event.type == Gdk.EventType.BUTTON_PRESS and event.button == 3:
+        # need to keep a reference here of menu, otherwise it gets
+        # deleted when it goes out of scope and no menu is visible
+        # (bug #806949)
+        self.menu = menu = Gtk.Menu()
+        item_select_none = Gtk.MenuItem.new_with_mnemonic(_("_Deselect All"))
         item_select_none.connect("activate", self.select_none_updgrades)
-        menu.add(item_select_none)
+        menu.append(item_select_none)
         num_updates = self.cache.installCount
         if num_updates == 0:
             item_select_none.set_property("sensitive", False)
-        item_select_all = gtk.MenuItem(_("_Check All"))
+        item_select_all = Gtk.MenuItem.new_with_mnemonic(_("Select _All"))
         item_select_all.connect("activate", self.select_all_updgrades)
-        menu.add(item_select_all)
-        menu.popup(None, None, None, 0, event.time)
+        menu.append(item_select_all)
         menu.show_all()
+        menu.popup_for_device(
+            None, None, None, None, None, event.button, event.time)
+        menu.show()
         return True
 
   def select_all_updgrades(self, widget):
@@ -520,14 +532,14 @@ class UpdateManager(SimpleGtkbuilderApp):
   def setBusy(self, flag):
       """ Show a watch cursor if the app is busy for more than 0.3 sec.
       Furthermore provide a loop to handle user interface events """
-      if self.window_main.window is None:
+      if self.window_main.get_window() is None:
           return
       if flag == True:
-          self.window_main.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
+          self.window_main.get_window().set_cursor(Gdk.Cursor.new(Gdk.CursorType.WATCH))
       else:
-          self.window_main.window.set_cursor(None)
-      while gtk.events_pending():
-          gtk.main_iteration()
+          self.window_main.get_window().set_cursor(None)
+      while Gtk.events_pending():
+          Gtk.main_iteration()
 
   def refresh_updates_count(self):
       self.button_install.set_sensitive(self.cache.installCount)
@@ -550,14 +562,17 @@ class UpdateManager(SimpleGtkbuilderApp):
               #else:
               #    self.button_install.set_sensitive(True)
               self.button_install.set_sensitive(True)
+              self.unity.set_install_menuitem_visible(True)
           else:
               if inst_count > 0:
                   download_str = ngettext("The update has already been downloaded, but not installed",
                   "The updates have already been downloaded, but not installed", inst_count)
                   self.button_install.set_sensitive(True)
+                  self.unity.set_install_menuitem_visible(True)
               else:
                   download_str = _("There are no updates to install")
                   self.button_install.set_sensitive(False)
+                  self.unity.set_install_menuitem_visible(False)
               self.image_downsize.set_sensitive(False)
           # TRANSLATORS: this allows to switch the order of the count of
           #              updates and the download size string (if needed)
@@ -573,9 +588,9 @@ class UpdateManager(SimpleGtkbuilderApp):
           self.hbox_downsize.show()
           self.vbox_alerts.show()
 
-  def _get_last_apt_get_update_hours(self):
+  def _get_last_apt_get_update_minutes(self):
       """
-      Return the number of hours since the last successful apt-get update
+      Return the number of minutes since the last successful apt-get update
       
       If the date is unknown, return "None"
       """
@@ -584,19 +599,20 @@ class UpdateManager(SimpleGtkbuilderApp):
       # calculate when the last apt-get update (or similar operation)
       # was performed
       mtime = os.stat("/var/lib/apt/periodic/update-success-stamp")[stat.ST_MTIME]
-      ago_hours = int((time.time() - mtime) / (60*60) )
-      return ago_hours
+      ago_minutes = int((time.time() - mtime) / 60 )
+      return ago_minutes
 
   def _get_last_apt_get_update_text(self):
       """
       return a human readable string with the information when
       the last apt-get update was run
       """
-      ago_hours = self._get_last_apt_get_update_hours()
-      if ago_hours is None:
+      ago_minutes = self._get_last_apt_get_update_minutes()
+      if ago_minutes is None:
           return _("It is unknown when the package information was "
-                   "updated last. Please try clicking on the 'Check' "
+                   "updated last. Please click the 'Check' "
                    "button to update the information.")
+      ago_hours = int( ago_minutes / 60 )
       ago_days = int( ago_hours / 24 )
       if ago_days > self.NO_UPDATE_WARNING_DAYS:
 	  return _("The package information was last updated %(days_ago)s "
@@ -611,11 +627,18 @@ class UpdateManager(SimpleGtkbuilderApp):
           return ngettext("The package information was last updated %(hours_ago)s hour ago.",
                           "The package information was last updated %(hours_ago)s hours ago.",
                           ago_hours) % { "hours_ago" : ago_hours, }
+      elif ago_minutes >= 45:
+          # TRANSLATORS: only in plural form, as %s minutes ago is one of 15, 30, 45 minutes ago
+          return _("The package information was last updated about %s minutes ago.")%45
+      elif ago_minutes >= 30:
+          return _("The package information was last updated about %s minutes ago.")%30
+      elif ago_minutes >= 15:
+          return _("The package information was last updated about %s minutes ago.")%15
       else:
-          return _("The package information was last updated less than one hour ago.")
+          return _("The package information was just updated.")
       return None
 
-  def update_last_updated_text(self):
+  def update_last_updated_text(self, user_data):
       """timer that updates the last updated text """
       #print "update_last_updated_text"
       num_updates = self.cache.installCount
@@ -633,6 +656,10 @@ class UpdateManager(SimpleGtkbuilderApp):
       self.refresh_updates_count()
       num_updates = self.cache.installCount
       text_label_main = _("Software updates correct errors, eliminate security vulnerabilities and provide new features.")
+
+      # setup unity stuff
+      self.unity.set_updates_count(num_updates)
+
       if num_updates == 0:
           text_header= "<big><b>%s</b></big>"  % _("Your system is up-to-date")
           self.label_downsize.set_text("\n")
@@ -640,26 +667,27 @@ class UpdateManager(SimpleGtkbuilderApp):
               self.notebook_details.set_sensitive(False)
               self.treeview_update.set_sensitive(False)
           self.button_install.set_sensitive(False)
+          self.unity.set_install_menuitem_visible(False)
           self.button_close.grab_default()
           self.textview_changes.get_buffer().set_text("")
           self.textview_descr.get_buffer().set_text("")
           if self._get_last_apt_get_update_text() is not None:
               text_label_main = self._get_last_apt_get_update_text()
-	      if self._get_last_apt_get_update_hours() > self.NO_UPDATE_WARNING_DAYS*24:
+	      if self._get_last_apt_get_update_minutes()> self.NO_UPDATE_WARNING_DAYS*24*60:
 			text_header = "<big><b>%s</b></big>"  % _("Software updates may be available for your computer.")
           # add timer to ensure we update the information when the 
           # last package count update was performed
-          glib.timeout_add_seconds(10, self.update_last_updated_text)
+          GObject.timeout_add_seconds(10, self.update_last_updated_text, None)
       else:
           # show different text on first run (UX team suggestion)
-          firstrun = self.gconfclient.get_bool("/apps/update-manager/first_run")
+          firstrun = self.settings.get_boolean("first-run")
           if firstrun:
               text_header = "<big><b>%s</b></big>" % _("Welcome to Ubuntu")
               if is_unity_running():
-                  text_label_main = _("These software updates have been issued since Ubuntu was released. If you don't want to install them now, choose \"Update Manager\" from Applications later.")
+                  text_label_main = _("These software updates have been issued since this version of Ubuntu was released. If you don't want to install them now, choose \"Update Manager\" from Applications later.")
               else:   
-                  text_label_main = _("These software updates have been issued since Ubuntu was released. If you don't want to install them now, choose \"Update Manager\" from the Administration Menu later.")
-              self.gconfclient.set_bool("/apps/update-manager/first_run", False)
+                  text_label_main = _("These software updates have been issued since this version of Ubuntu was released. If you don't want to install them now, choose \"Update Manager\" from the Administration Menu later.")
+              self.settings.set_boolean("first-run", False)
           else:
               text_header = "<big><b>%s</b></big>" % _("Software updates are available for this computer")
               if is_unity_running():
@@ -669,7 +697,8 @@ class UpdateManager(SimpleGtkbuilderApp):
           self.notebook_details.set_sensitive(True)
           self.treeview_update.set_sensitive(True)
           self.button_install.grab_default()
-          self.treeview_update.set_cursor(1)
+          self.treeview_update.set_cursor(
+              Gtk.TreePath.new_from_string("1"), None, False)
       self.label_header.set_markup(text_header)
       self.label_main_details.set_text(text_label_main)
       return True
@@ -681,11 +710,11 @@ class UpdateManager(SimpleGtkbuilderApp):
                                         True,
                                         0,
                                         True)
-    self.gconfclient.set_bool("/apps/update-manager/show_details",expanded)
+    self.settings.set_boolean("show-details",expanded)
     if expanded:
       self.on_treeview_update_cursor_changed(self.treeview_update)
 
-  def on_button_reload_clicked(self, widget):
+  def on_button_reload_clicked(self, widget, menuitem = None, data = None):
     #print "on_button_reload_clicked"
     self.check_metarelease()
     self.invoke_manager(UPDATE)
@@ -699,15 +728,17 @@ class UpdateManager(SimpleGtkbuilderApp):
         apt_pkg.pkgsystem_unlock()
     except SystemError:
         pass
-    cmd = ["/usr/bin/gksu", 
-           "--desktop", "/usr/share/applications/software-properties-gtk.desktop", 
-           "--", "/usr/bin/software-properties-gtk","--open-tab","2",
-           "--toplevel", "%s" % self.window_main.window.xid ]
+    cmd = ["/usr/bin/software-properties-gtk",
+           "--open-tab","2",
+           # FIXME: once get_xid() is available via introspections, add 
+           #        this back
+           #"--toplevel", "%s" % self.window_main.get_window().get_xid() 
+          ]
     self.window_main.set_sensitive(False)
     p = subprocess.Popen(cmd)
     while p.poll() is None:
-        while gtk.events_pending():
-            gtk.main_iteration()
+        while Gtk.events_pending():
+            Gtk.main_iteration()
         time.sleep(0.05)
     self.fillstore()
 
@@ -762,7 +793,7 @@ class UpdateManager(SimpleGtkbuilderApp):
                                    "/org/freedesktop/ConsoleKit/Manager")
         iface = dbus.Interface(proxy_obj, "org.freedesktop.ConsoleKit.Manager")
         iface.Restart()
-    except dbus.DBusException, e:
+    except dbus.DBusException:
         pass
 
   def invoke_manager(self, action):
@@ -776,16 +807,15 @@ class UpdateManager(SimpleGtkbuilderApp):
 
     # set window to insensitive
     self.window_main.set_sensitive(False)
-    self.window_main.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
+    self.window_main.get_window().set_cursor(Gdk.Cursor.new(Gdk.CursorType.WATCH))
 #
     # do it
     if action == UPDATE:
         self.install_backend.update()
     elif action == INSTALL:
         # If the progress dialog should be closed automatically afterwards
-        gconfclient =  gconf.client_get_default()
-        close_on_done = gconfclient.get_bool("/apps/update-manager/"
-                                             "autoclose_install_window")
+        settings = Gio.Settings("com.ubuntu.update-manager")
+        close_on_done = settings.get_boolean("autoclose-install-window")
         # Get the packages which should be installed and update
         pkgs_install = []
         pkgs_upgrade = []
@@ -813,12 +843,12 @@ class UpdateManager(SimpleGtkbuilderApp):
         allow_sleep(self.sleep_dev, self.sleep_cookie)
         self.sleep_cookie = self.sleep_dev = None
     self.window_main.set_sensitive(True)
-    self.window_main.window.set_cursor(None)
+    self.window_main.get_window().set_cursor(None)
 
   def _on_network_alert(self, watcher, state):
       # do not set the buttons to sensitive/insensitive until NM
       # can deal with dialup connections properly
-      if state == NetworkManagerHelper.NM_STATE_CONNECTING:
+      if state in NetworkManagerHelper.NM_STATE_CONNECTING_LIST:
           self.label_offline.set_text(_("Connecting..."))
           #self.button_reload.set_sensitive(False)
           self.refresh_updates_count()
@@ -826,8 +856,8 @@ class UpdateManager(SimpleGtkbuilderApp):
           self.vbox_alerts.show()
           self.connected = False
       # in doubt (STATE_UNKNOWN), assume connected
-      elif state in (NetworkManagerHelper.NM_STATE_CONNECTED,
-                     NetworkManagerHelper.NM_STATE_UNKNOWN):
+      elif (state in NetworkManagerHelper.NM_STATE_CONNECTED_LIST or 
+           state == NetworkManagerHelper.NM_STATE_UNKNOWN):
           #self.button_reload.set_sensitive(True)
           self.refresh_updates_count()
           self.hbox_offline.hide()
@@ -860,13 +890,15 @@ class UpdateManager(SimpleGtkbuilderApp):
       else:
           self.hbox_on_3g.hide()
           self.hbox_roaming.hide()
-
   def row_activated(self, treeview, path, column):
       iter = self.store.get_iter(path)
+          
       pkg = self.store.get_value(iter, LIST_PKG)
       origin = self.store.get_value(iter, LIST_ORIGIN)
       if pkg is not None:
           return
+      self.toggle_from_origin(pkg, origin, True)
+  def toggle_from_origin(self, pkg, origin, select_all = True ):
       self.setBusy(True)
       actiongroup = apt_pkg.ActionGroup(self.cache._depcache)
       for pkg in self.list.pkgs[origin]:
@@ -875,7 +907,7 @@ class UpdateManager(SimpleGtkbuilderApp):
               pkg.mark_keep()
           elif not (pkg.name in self.list.held_back):
               #print "marking install: ", pkg.name
-              pkg.mark_install(autoFix=False,autoInst=False)
+              pkg.mark_install(auto_fix=False,auto_inst=False)
       # check if we left breakage
       if self.cache._depcache.broken_count:
           Fix = apt_pkg.ProblemResolver(self.cache._depcache)
@@ -884,14 +916,21 @@ class UpdateManager(SimpleGtkbuilderApp):
       self.treeview_update.queue_draw()
       del actiongroup
       self.setBusy(False)
-
-
+  
   def toggled(self, renderer, path):
     """ a toggle button in the listview was toggled """
     iter = self.store.get_iter(path)
     pkg = self.store.get_value(iter, LIST_PKG)
+    origin = self.store.get_value(iter, LIST_ORIGIN)
     # make sure that we don't allow to toggle deactivated updates
     # this is needed for the call by the row activation callback
+    if pkg is None:
+	
+	toggled_value = not self.store.get_value(iter, LIST_TOGGLE_CHECKED)
+	self.toggle_from_origin(pkg, origin, toggled_value)
+	self.store.set_value(iter, LIST_TOGGLE_CHECKED, toggled_value )
+	self.treeview_update.queue_draw()
+	return 
     if pkg is None or pkg.name in self.list.held_back:
         return False
     self.setBusy(True)
@@ -902,7 +941,10 @@ class UpdateManager(SimpleGtkbuilderApp):
             Fix = apt_pkg.ProblemResolver(self.cache._depcache)
             Fix.resolve_by_keep()
     else:
-        pkg.mark_install()
+        try:
+            pkg.mark_install()
+        except SystemError:
+            pass
     self.treeview_update.queue_draw()
     self.refresh_updates_count()
     self.setBusy(False)
@@ -914,48 +956,31 @@ class UpdateManager(SimpleGtkbuilderApp):
     """
     self.toggled(None, path)
 
-  def on_window_main_size_allocate(self,arg1,arg2):
-    """ 
-    recalculates headline labels on window resize to work around
-    problems with gtk word wrapping 
-    (http://bugzilla.gnome.org/show_bug.cgi?id=101968)
-    """
-    # this number is based on border width 
-    # (2*main_border_with + icon width + 2*icon_border_with)
-    #     2*18 + 48 + 2*12 
-    border_space = 96
-    width, height = self.window_main.get_size()
-    #print "on_window_main_size_allocate", width, height
-    self.label_main_details.set_size_request(width - border_space ,-1)
-    self.label_header.set_size_request(width - border_space,-1)
-    self.label_downsize.set_size_request(width - border_space,-1)
-    self.label_roaming.set_size_request(width - border_space,-1)
-
   def exit(self):
     """ exit the application, save the state """
     self.save_state()
-    #gtk.main_quit()
+    #Gtk.main_quit()
     sys.exit(0)
 
   def save_state(self):
     """ save the state  (window-size for now) """
-    (x,y) = self.window_main.get_size()
-    self.gconfclient.set_pair("/apps/update-manager/window_size",
-                              gconf.VALUE_INT, gconf.VALUE_INT, x, y)
+    (w, h) = self.window_main.get_size()
+    self.settings.set_int("window-width", w)
+    self.settings.set_int("window-height", h)
 
   def restore_state(self):
     """ restore the state (window-size for now) """
-    expanded = self.gconfclient.get_bool("/apps/update-manager/show_details")
+    expanded = self.settings.get_boolean("show-details")
     self.expander_details.set_expanded(expanded)
     self.vbox_updates.set_child_packing(self.expander_details,
                                         expanded,
                                         True,
                                         0,
                                         True)
-    (x,y) = self.gconfclient.get_pair("/apps/update-manager/window_size",
-                                      gconf.VALUE_INT, gconf.VALUE_INT)
-    if x > 0 and y > 0:
-      self.window_main.resize(x,y)
+    w = self.settings.get_int("window-width")
+    h = self.settings.get_int("window-height")
+    if w > 0 and h > 0:
+      self.window_main.resize(w, h)
 
   def fillstore(self):
     # use the watch cursor
@@ -973,18 +998,18 @@ class UpdateManager(SimpleGtkbuilderApp):
                   "package and include the following error message:\n"),
                 e)
                )
-        dialog = gtk.MessageDialog(self.window_main,
-                                   0, gtk.MESSAGE_ERROR,
-                                   gtk.BUTTONS_CLOSE,"")
+        dialog = Gtk.MessageDialog(self.window_main,
+                                   0, Gtk.MessageType.ERROR,
+                                   Gtk.ButtonsType.CLOSE,"")
         dialog.set_markup(msg)
-        dialog.vbox.set_spacing(6)
+        dialog.get_content_area().set_spacing(6)
         dialog.run()
         dialog.destroy()
         sys.exit(1)
     self.store.clear()
     self.list = UpdateList(self)
-    while gtk.events_pending():
-        gtk.main_iteration()
+    while Gtk.events_pending():
+        Gtk.main_iteration()
 
     # fill them again
     try:
@@ -1002,11 +1027,11 @@ class UpdateManager(SimpleGtkbuilderApp):
                   "package and include the following error message:"),
                 e)
                )
-        dialog = gtk.MessageDialog(self.window_main,
-                                   0, gtk.MESSAGE_ERROR,
-                                   gtk.BUTTONS_CLOSE,"")
+        dialog = Gtk.MessageDialog(self.window_main,
+                                   0, Gtk.MessageType.ERROR,
+                                   Gtk.ButtonsType.CLOSE,"")
         dialog.set_markup(msg)
-        dialog.vbox.set_spacing(6)
+        dialog.get_content_area().set_spacing(6)
         dialog.run()
         dialog.destroy()
     if self.list.num_updates > 0:
@@ -1053,11 +1078,11 @@ class UpdateManager(SimpleGtkbuilderApp):
   def error(self, summary, details):
       " helper function to display a error message "
       msg = ("<big><b>%s</b></big>\n\n%s\n" % (summary, details) )
-      dialog = gtk.MessageDialog(self.window_main,
-                                 0, gtk.MESSAGE_ERROR,
-                                 gtk.BUTTONS_CLOSE,"")
+      dialog = Gtk.MessageDialog(self.window_main,
+                                 0, Gtk.MessageType.ERROR,
+                                 Gtk.ButtonsType.CLOSE,"")
       dialog.set_markup(msg)
-      dialog.vbox.set_spacing(6)
+      dialog.get_content_area().set_spacing(6)
       dialog.run()
       dialog.destroy()
 
@@ -1084,12 +1109,12 @@ class UpdateManager(SimpleGtkbuilderApp):
     # get the lock
     try:
         apt_pkg.pkgsystem_lock()
-    except SystemError, e:
+    except SystemError:
         pass
-        #d = gtk.MessageDialog(parent=self.window_main,
-        #                      flags=gtk.DIALOG_MODAL,
-        #                      type=gtk.MESSAGE_ERROR,
-        #                      buttons=gtk.BUTTONS_CLOSE)
+        #d = Gtk.MessageDialog(parent=self.window_main,
+        #                      flags=Gtk.DialogFlags.MODAL,
+        #                      type=Gtk.MessageType.ERROR,
+        #                      buttons=Gtk.ButtonsType.CLOSE)
         #d.set_markup("<big><b>%s</b></big>\n\n%s" % (
         #    _("Only one software management tool is allowed to "
         #      "run at the same time"),
@@ -1119,11 +1144,11 @@ class UpdateManager(SimpleGtkbuilderApp):
                 "Please use the package manager \"Synaptic\" or run "
 		"\"sudo apt-get install -f\" in a terminal to fix "
 		"this issue at first.")))
-        dialog = gtk.MessageDialog(self.window_main,
-                                   0, gtk.MESSAGE_ERROR,
-                                   gtk.BUTTONS_CLOSE,"")
+        dialog = Gtk.MessageDialog(self.window_main,
+                                   0, Gtk.MessageType.ERROR,
+                                   Gtk.ButtonsType.CLOSE,"")
         dialog.set_markup(msg)
-        dialog.vbox.set_spacing(6)
+        dialog.get_content_area().set_spacing(6)
         dialog.run()
         dialog.destroy()
         sys.exit(1)
@@ -1133,7 +1158,7 @@ class UpdateManager(SimpleGtkbuilderApp):
   def check_auto_update(self):
       # Check if automatic update is enabled. If not show a dialog to inform
       # the user about the need of manual "reloads"
-      remind = self.gconfclient.get_bool("/apps/update-manager/remind_reload")
+      remind = self.settings.get_boolean("remind-reload")
       if remind == False:
           return
 
@@ -1143,7 +1168,7 @@ class UpdateManager(SimpleGtkbuilderApp):
           self.dialog_manual_update.set_title("")
           res = self.dialog_manual_update.run()
           self.dialog_manual_update.hide()
-          if res == gtk.RESPONSE_YES:
+          if res == Gtk.ResponseType.YES:
               self.on_button_reload_clicked(None)
 
   def check_all_updates_installable(self):
@@ -1157,7 +1182,7 @@ class UpdateManager(SimpleGtkbuilderApp):
       self.dialog_dist_upgrade.set_title("")
       res = self.dialog_dist_upgrade.run()
       self.dialog_dist_upgrade.hide()
-      if res == gtk.RESPONSE_YES:
+      if res == Gtk.ResponseType.YES:
           os.execl("/usr/bin/gksu",
                    "/usr/bin/gksu", "--desktop",
                    "/usr/share/applications/update-manager.desktop",
@@ -1166,14 +1191,14 @@ class UpdateManager(SimpleGtkbuilderApp):
 
   def check_metarelease(self):
       " check for new meta-release information "
-      gconfclient = SafeGConfClient()
+      settings = Gio.Settings("com.ubuntu.update-manager")
       self.meta = MetaRelease(self.options.devel_release,
                               self.options.use_proposed)
       self.meta.connect("dist_no_longer_supported",self.dist_no_longer_supported)
       # check if we are interessted in dist-upgrade information
       # (we are not by default on dapper)
-      if self.options.check_dist_upgrades or \
-             gconfclient.get_bool("/apps/update-manager/check_dist_upgrades"):
+      if (self.options.check_dist_upgrades or
+          settings.get_boolean("check-dist-upgrades")):
           self.meta.connect("new_dist_available",self.new_dist_available)
       
 
@@ -1183,10 +1208,10 @@ class UpdateManager(SimpleGtkbuilderApp):
     # check for new distributin information
     self.check_metarelease()
 
-    while gtk.events_pending():
-      gtk.main_iteration()
+    while Gtk.events_pending():
+      Gtk.main_iteration()
 
     self.fillstore()
     self.check_auto_update()
     self.alert_watcher.check_alert_state()
-    gtk.main()
+    Gtk.main()
