@@ -10,9 +10,9 @@ import time
 import urllib2
 import unittest
 
+from urllib2 import urlopen
 
 from BaseHTTPServer import BaseHTTPRequestHandler
-from SimpleHTTPServer import SimpleHTTPRequestHandler
 from SocketServer import TCPServer
 
 class SillyProxyRequestHandler(BaseHTTPRequestHandler):
@@ -35,8 +35,8 @@ httpd = TCPServer(("", PORT), Handler)
 
 
 sys.path.insert(0, "../")
-from UpdateManager.Core.MetaRelease import *
-from UpdateManager.Core.DistUpgradeFetcherCore import *
+from UpdateManager.Core.MetaRelease import MetaReleaseCore, Dist
+#from UpdateManager.Core.DistUpgradeFetcherCore import 
 
 
 def get_new_dist(current_release):
@@ -106,6 +106,27 @@ class TestMetaReleaseCore(unittest.TestCase):
                         logging.debug),
                         "download with no proxy failed")
 
+    def test_get_uri_query_string(self):
+        # test with fake data
+        d = Dist("oneiric", "11.10", "2011-10-10", True)
+        meta = MetaReleaseCore()
+        q = meta._get_release_notes_uri_query_string(d)
+        self.assertTrue("os=ubuntu" in q)
+        self.assertTrue("ver=11.10" in q)
+
+    def test_html_uri_real(self):
+        os.environ["http_proxy"]=""
+        os.environ["META_RELEASE_FAKE_CODENAME"] = "maverick"
+        meta = MetaReleaseCore(forceDownload=True)
+        while meta.downloading:
+            time.sleep(0.1)
+        uri = meta.new_dist.releaseNotesHtmlUri
+        f = urlopen(uri)
+        data = f.read()
+        self.assertTrue(len(data) > 0)
+        self.assertTrue("<html>" in data)
+        del os.environ["META_RELEASE_FAKE_CODENAME"]
+
 if __name__ == '__main__':
     if len(sys.argv) > 1 and sys.argv[1] == "-v":
         logging.basicConfig(level=logging.DEBUG)
